#
# Configuration file for using the xslt library
#
XSLT_LIBDIR="-L/clangarm64/lib"
XSLT_LIBS="-lxslt -L/clangarm64/lib -lxml2 "
XSLT_PRIVATE_LIBS=""
XSLT_INCLUDEDIR="-I/clangarm64/include"
MODULE_VERSION="xslt-1.1.43"
